/**
* Common elements
*/

body {
	font: 12px Verdana, sans-serif;
	background-color: white;
	color:            black;
	margin-top:    6px;
	margin-bottom: 30px;
	margin-left:   12px;
	margin-right:  12px;
}

h1 {
	font: bold 18px Verdana, sans-serif;
	line-height:   26px;
	margin-top:    12px;
	margin-bottom: 15px;
	margin-left:    0;
	margin-right:   7px;
	background-color: #e6eaf6;
	padding-left:   10px;
	padding-top:    2px;
	padding-bottom: 4px;
}

h3 {
	font: bold 13px Verdana, sans-serif;
	line-height:   26px;
	margin-top:    12px;
	margin-bottom:  0;
	margin-left:    0;
	margin-right:   7px;
	padding-left:   4px;
}

ul {
	margin-top: 0;
}

p, li {
	font: 9pt/135% sans-serif;
	margin-top:    1px;
	margin-bottom: 0;
}

a, a:link, a:visited {
	color: #0000cc;
}

hr {
	height: 0;
	border: solid gray 0;
	border-top-width: thin;
	width: 700px;
}

table.table td {
	font: 9pt sans-serif;
	padding-top:    1px;
	padding-bottom: 1px;
	padding-left:   5px;
	padding-right:  5px;
}

table.table td.header {
	background-color: #cccccc;
	padding-top:    2px;
	padding-bottom: 2px;
	font-weight: bold;
}

table.table tr.even_files {
	background-color: #fefefe;
}

table.table tr.odd_files {
	background-color: #e9e9e9;
}

table.dump {
	border-top:  solid 1px #cccccc;
	border-left: solid 1px #cccccc;
	margin: 2px;
}

table.dump td {
	font: 9pt sans-serif;
	padding-top:    1px;
	padding-bottom: 1px;
	padding-left:   5px;
	padding-right:  5px;
	border-right:  solid 1px #cccccc;
	border-bottom: solid 1px #cccccc;
}

td.dump_string {
	font-weight: bold;
	color: #006600;
	font-family: Zawgyi-One,sans-serif;
}

td.dump_integer {
	color: #CC0000;
	font-weight: bold;
}

td.dump_double {
	color: #FF9900;
	font-weight: bold;
}

td.dump_boolean {
	color: #0000FF;
	font-weight: bold;
}

.error {
	color: red
}


/**
* Tool Tips
*/

.tooltip {
    font: 9pt sans-serif;
    background: #ffffe1;
    color: 	black;
    border: 	black 1px solid;
    margin: 	2px;
    padding: 	7px;
    position: 	absolute;
    top: 	10px;
    left: 	10px;
    z-index: 	10000;
    visibility: hidden;
}

.tooltip p {
     margin-top:   -2px;
     margin-bottom: 4px;
}


/**
* Forms
*/

table.form td {
 	font: 9pt/135% sans-serif;
 	padding: 2px;
}

select, input {
	font: 9pt/135% sans-serif;
}

.select, .field {
	width: 260px;
}

#sel_field {
	width: 85px;
}

.button {
	margin-top: 10px;
}
